@@ -690,6 +690,10 @@ class DataClientV3(DataClient):
         return data
 
     def delete_student(self, params, school_id):
+        student_id = params.get("student_id", None)
+        if student_id:
+            code, data = delete_student_req(student_id, school_id)
+            return code, data
         data = self.get_student_info(params, school_id)
         if len(data) > 1:
             return ERROR_PARAMS, "查询学生信息不唯一"
