@@ -298,3 +298,17 @@ class NirvanaRequester(Requester):
                 "force": True}
         res = self._delete_method(route, data)
         return res
+
+    def delete_subject(self, uid):
+        route = "/api/subject/{}/".format(uid)
+        data = {"soft": False,
+                "force": True}
+        res = self._delete_method(route, data)
+        return res
+
+    def upload_face_file(self, file_path, data):
+        route = "/api/upload_face_img/"
+        data["category"] = "face"
+        with open(file_path, 'rb') as f:
+            res = self._post_file_method(route, {'file': f}, data=data)
+        return res
