@@ -102,5 +102,5 @@ class ClassroomSync(BaseSync):
         if not self.classroom_map:
             logger.info("没有教室信息")
             return
-        self.client.create_classrooms(self.school_id, self.classroom_list)
+        # self.client.create_classrooms(self.school_id, self.classroom_list)
         self.close_db()
