@@ -39,5 +39,12 @@ class ClassroomSync(BaseSync):
                 classroom.category = RoomType.TYPE_PUBLIC
                 logger.info("classroom {} has no name".format(rd['locationName']))
             classroom_list.append(classroom)
-        self.client.create_classrooms(self.school_id, classroom_list)
+        try:
+            self.client.create_classrooms(self.school_id, classroom_list)
+        except (Exception,):
+            for classroom_item in classroom_list:
+                try:
+                    self.client.create_classrooms(self.school_id, [classroom_item])
+                except (Exception,):
+                    continue
         logging.info("{}/{} has class".format(total, len(classroom_list)))
