@@ -126,14 +126,17 @@ class CourseSyncV2(BaseSync2):
         return used_classroom
 
     def sync(self):
-        response = self.nice_requester.get_table(current=False)
+        response = self.nice_requester.get_table(current=True)
         begin_datetime = datetime.datetime.now()
         end_datetime = begin_datetime + datetime.timedelta(days=60)
         begin_date, end_date = date2str(begin_datetime.date()), date2str(end_datetime.date())
-        semester_name = response['semester'] or "当前学期"
+        semester_name = "{}_{}".format(response['semester'] or "当前学期", str(uuid.uuid4())[:4])
         semester = SemesterV2(name=semester_name, begin_date=begin_date, end_date=end_date,
                               number=get_md5_hash(semester_name)[:20])
-        rest_table = RestTableV2(name="全校作息", number=get_md5_hash("全校作息")[:20], semester_name=semester.name)
+        # rest_table_name = "{}_{}".format("全校作息", str(uuid.uuid4())[:4])
+        rest_table_name = "全校作息"
+        rest_table = RestTableV2(name=rest_table_name, number=get_md5_hash(rest_table_name)[:20],
+                                 semester_name=semester.name)
         rest_table_info = response.get('timeSettings', [])
         if not response.get('schedule', None):
             return
