@@ -1,3 +1,4 @@
+import time
 from sync.student import StudentSync
 from sync.teacher import TeacherSync
 from sync.clas import ClassSync
@@ -77,11 +78,12 @@ def start_sync_v2():
         course_sync.is_walking = is_walking
         course_sync.classroom_map = classroom_sync.id_num_map
         course_sync.start()
+        time.sleep(5)
 
 
 def init_basic_data():
     special_number = None
-    special_number_list = []
+    special_number_list = ["3550"]
     logger.info(">>>Start profession sync")
     school_sync = SchoolSync(special_number=special_number)
     school_sync.start()
