@@ -166,7 +166,7 @@ class CourseTableSync(BaseSync):
                     course = course_map[course_name]
                 else:
                     course_number = get_md5_hash(course_name)
-                    course = Course(number=course_number, name=course_name[:63], teacher_number=teacher_number,
+                    course = Course(number=course_number, name=course_number, teacher_number=teacher_number,
                                     classroom_number=classroom_num, subject_number=subject_number,
                                     begin_week=time_result['begin_week'], end_week=time_result['end_week'],
                                     required_student=False, is_present=True)
@@ -234,7 +234,7 @@ class CourseTableSync(BaseSync):
                     course = self.course_map[course_name]
                 else:
                     course_number = get_md5_hash(course_name)
-                    course = Course(number=course_number, name=course_name[:63], teacher_number=teacher_number,
+                    course = Course(number=course_number, name=course_number, teacher_number=teacher_number,
                                     classroom_number=classroom_num, subject_number=subject_number, is_present=True,
                                     begin_week=begin_week, end_week=end_week, required_student=False)
                     self.course_map[course_name] = course
@@ -326,7 +326,7 @@ class CourseTableSync(BaseSync):
                     course = course_map[course_name]
                 else:
                     course_number = get_md5_hash(course_name)
-                    course_data = dict(number=course_number, name=course_name[:63], classroom_number=classroom_num,
+                    course_data = dict(number=course_number, name=course_number, classroom_number=classroom_num,
                                        subject_number=subject_number, is_present=True, begin_week=begin_week,
                                        end_week=end_week, required_student=False)
                     if teacher_number:
@@ -343,11 +343,11 @@ class CourseTableSync(BaseSync):
     def sync(self):
         self.record(">>>Start course sync")
         t1 = time.time()
-        # self.get_bk_course()
+        self.get_bk_course()
         self.combine_course()
         self.record(">>>Total have {} courses".format(len(self.course_map)))
-        # if self.need_relate_student:
-        #     self.relate_student()
+        if self.need_relate_student:
+            self.relate_student()
         self.record(">>>Get yjs course")
         yjs_course = self.get_yjs_course()
         self.course_map.update(yjs_course)
