@@ -29,7 +29,7 @@ def start_avatar_sync():
     start_time = time.time()
     avatar_sync = AvatarSync()
     avatar_sync.start()
-    logger.info("course avatar sync used: {}s".format(round(time.time() - start_time, 4)))
+    logger.info("avatar sync used: {}s".format(round(time.time() - start_time, 4)))
 
 
 def start_crawl():
